# INSTALLATION
> pip3 install auto_chromedriver 

# USAGE

> Calling The Module

* import auto_chromedriver
* ac=auto_chromedriver.auto_chromedriver_installer()

> To install chromedriver automatically

* ac.install()

> To see the version of chromium

* ac.chromium_version()
